summaryrefslogtreecommitdiff
path: root/tests/test_common.h
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_common.h')
-rw-r--r--tests/test_common.h95
1 files changed, 81 insertions, 14 deletions
diff --git a/tests/test_common.h b/tests/test_common.h
index ef21c3b5..0e2c8d6c 100644
--- a/tests/test_common.h
+++ b/tests/test_common.h
@@ -7,49 +7,116 @@
#ifndef VBOOT_REFERENCE_TEST_COMMON_H_
#define VBOOT_REFERENCE_TEST_COMMON_H_
+#include <stdio.h>
+
+/* Used to get a line number as a constant string. Need to stringify it twice */
+#define STRINGIFY(x) #x
+#define TOSTRING(x) STRINGIFY(x)
+
extern int gTestSuccess;
/* Return 1 if result is equal to expected_result, else return 0.
* Also update the global gTestSuccess flag if test fails. */
-int TEST_EQ(int result, int expected_result, const char* testname);
+int test_eq(int result, int expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_EQ(result, expected, comment) \
+ test_eq(result, expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == " #expected, \
+ comment)
+
+#define TEST_EQ_S(result, expected) TEST_EQ(result, expected, NULL);
/* Return 0 if result is equal to not_expected_result, else return 1.
* Also update the global gTestSuccess flag if test fails. */
-int TEST_NEQ(int result, int not_expected_result, const char* testname);
+int test_neq(int result, int not_expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_NEQ(result, not_expected, comment) \
+ test_neq(result, not_expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " != " #not_expected, \
+ comment)
/* Return 1 if result pointer is equal to expected_result pointer,
* else return 0. Does not check pointer contents, only the pointer
* itself. Also update the global gTestSuccess flag if test fails. */
-int TEST_PTR_EQ(const void* result, const void* expected_result,
- const char* testname);
+int test_ptr_eq(const void* result, const void* expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_PTR_EQ(result, expected, comment) \
+ test_ptr_eq(result, expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == " #expected, \
+ comment)
/* Return 1 if result pointer is not equal to expected_result pointer,
* else return 0. Does not check pointer contents, only the pointer
* itself. Also update the global gTestSuccess flag if test fails. */
-int TEST_PTR_NEQ(const void* result, const void* expected_result,
- const char* testname);
+int test_ptr_neq(const void* result, const void* not_expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_PTR_NEQ(result, not_expected, comment) \
+ test_ptr_neq(result, not_expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " != " #not_expected, \
+ comment)
/* Return 1 if result string is equal to expected_result string,
* else return 0. Also update the global gTestSuccess flag if test fails. */
-int TEST_STR_EQ(const char* result, const char* expected_result,
- const char* testname);
+int test_str_eq(const char* result, const char* expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_STR_EQ(result, expected, comment) \
+ test_str_eq(result, expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == " #expected, \
+ comment)
-/* Return 1 if result string is not equal to not_expected_result string,
+/* Return 1 if result string is not equal to not_expected string,
* else return 0. Also update the global gTestSuccess flag if test fails. */
-int TEST_STR_NEQ(const char* result, const char* not_expected_result,
- const char* testname);
+int test_str_neq(const char* result, const char* not_expected,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_STR_NEQ(result, not_expected, comment) \
+ test_str_neq(result, not_expected, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " != " #not_expected, \
+ comment)
/* Return 1 if the result is true, else return 0.
* Also update the global gTestSuccess flag if test fails. */
-int TEST_TRUE(int result, const char* testname);
+int test_true(int result,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_TRUE(result, comment) \
+ test_true(result, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == true", \
+ comment)
/* Return 1 if the result is false, else return 0.
* Also update the global gTestSuccess flag if test fails. */
-int TEST_FALSE(int result, const char* testname);
+int test_false(int result,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_FALSE(result, comment) \
+ test_false(result, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == false", \
+ comment)
/* Return 1 if result is 0 (VB_ERROR_SUCCESS / VB2_SUCCESS), else return 0.
* Also update the global gTestSuccess flag if test fails. */
-int TEST_SUCC(int result, const char* testname);
+int test_succ(int result,
+ const char *preamble, const char *desc, const char *comment);
+
+#define TEST_SUCC(result, comment) \
+ test_succ(result, \
+ __FILE__ ":" TOSTRING(__LINE__), \
+ #result " == 0", \
+ comment)
/* ANSI Color coding sequences.
*